Auto ML Documentation
===============
This project aids in creating documentation required for any machine learning model. The documentation will have the following details:

1. EDA Results
2. Model Evaluation Results
3. Results on Deciles
4. Expected Result Tuning

Installing
============

.. code-block:: bash

    pip install mldocs

Usage
=====

.. code-block:: bash

    >>> import mladocs as mld
